@@ -2,22 +2,25 @@
 ### RS declaration generics
 
 #' @export
-`[[<-.ra_declaration` <- function(x, i, j, value ) {
+`[[<-.ra_declaration` <- function(x, i, j, value) {
   warning("Cannot assign into ra_declaration")
   NextMethod()
 }
 
 #' @export
-`$<-.ra_declaration` <- function(x, name, value ) {
+`$<-.ra_declaration` <- function(x, name, value) {
   warning("Cannot assign into ra_declaration")
   NextMethod()
 }
 
-ra_function <- function(this) UseMethod("ra_function", this)
+ra_function <- function(this)
+  UseMethod("ra_function", this)
 
-ra_probabilities     <- function(this) UseMethod("ra_probabilities", this)
+ra_probabilities     <-
+  function(this)
+    UseMethod("ra_probabilities", this)
 
-ra_function.default <- function(this){
+ra_function.default <- function(this) {
   stop("You must provide a random assignment declaration created by declare_ra().")
 }
 
@@ -27,20 +30,23 @@ ra_function.default <- function(this){
 
 
 #' @export
-`[[<-.rs_declaration` <- function(x, i, j, value ) {
+`[[<-.rs_declaration` <- function(x, i, j, value) {
   warning("Cannot assign into rs_declaration")
   NextMethod()
 }
 #' @export
-`$<-.rs_declaration` <- function(x, name, value ) {
+`$<-.rs_declaration` <- function(x, name, value) {
   warning("Cannot assign into rs_declaration")
   NextMethod()
 }
 
-rs_function <- function(this) UseMethod("rs_function", this)
+rs_function <- function(this)
+  UseMethod("rs_function", this)
 
-rs_probabilities     <- function(this) UseMethod("rs_probabilities", this)
+rs_probabilities     <-
+  function(this)
+    UseMethod("rs_probabilities", this)
 
-rs_function.default <- function(this){
+rs_function.default <- function(this) {
   stop("You must provide an random sampling object created by declare_rs().")
 }
